\name{modeRn-package}
\alias{modeRn-package}
\docType{package}
\title{
MOdelling Deposition and Erosion rates with RadioNuclides
}
\description{
MODERN is a transparent and easily adaptable model, to convert Fallout RadioNuclides (FRN) Inventories into quantitative estimates of both erosion and deposition processes.
}
\details{
\tabular{ll}{
Package: \tab modeRn\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2016-05-09\cr
License: \tab GPL-2\cr
}
~~ An overview of how to use the package, including the most important functions ~~
}
\author{
Main idea and concept: Christine Alewell[1] and Katrin Meusburger[1]\cr
Programming and conceptualizing: Enrico A. Chiaradia[2]\cr
Implementation and revising: Laura Arata[1]\cr\cr
[1] Environmental Geosciences, Department of Environmental Sciences, University of Basel, Switzerland\cr
[2] Department of Agricultural and Environmental Sciences (DiSAA) Section of Agricultural Hydraulic University of Milan, Italy\cr

Maintainer: Enrico A. Chiaradia <enrico.chiaradia@yahoo.it>

}
\references{
=== TODO ===
~~ Literature or other references for background information ~~
}
~~ Optionally other standard keywords, one per line, from file KEYWORDS in the R ~~
~~ documentation directory ~~
\keyword{ package }
\seealso{

}
\examples{
# load the library
library("modeRn")

# make a reference profile composed by 5 layers of thickness 3 cm
# and plot it
FRN = c(12, 21, 15, 13, 11, 9, 7.5, 4.5, 4, 3)
layer.thickness = 3
name = "Reference site"
RDP = createReferenceProfile(FRN,layer.thickness, name,
                             isotope = "137cs",
                             halfLife = "95144100000",
                             refTime = "2000", falloutTime = "1963",
                             timeFormat = "%Y")
plot(RDP, main = "A: measured depth profile RDP")

# add two simulated layers at the bottom of the profile
RDP.smooth = addSmoothedLayers(RDP, Depth = 2*3, NumLay=3)
plot(RDP.smooth, main = "B: simulated depth profile RDP.smooth")


# scenario 1:
# add two layers at the top to simulate deposition
RDP.smooth.dep1 = addDepositionLayers (RDP.smooth, FRN[1], 2)
plot(RDP.smooth.dep1, main = "C: simulated depth profile RDP.smooth.dep1")

# scenario 2:
# add one layers at the top to simulate deposition
RDP.smooth.dep2 = addDepositionLayers (RDP.smooth, mean(FRN[1:2]), 2)
plot(RDP.smooth.dep2, main = "D: simulated depth profile RDP.smooth.dep2")

# make a print
print(RDP.smooth.dep1)

# make sampling profile "A" and "B"
siteA = createSamplingProfile(78,30,"site A")
siteB = createSamplingProfile(115,30,"site B")

# find all possible results
MODERN_siteA = MODERN(RDP.smooth,siteA)
MODERN_siteB_1 = MODERN(RDP.smooth.dep1,siteB)
MODERN_siteB_2 = MODERN(RDP.smooth.dep2,siteB)

plot(MODERN_siteA, main = "A: RDP.smooth vs siteA")
plot(MODERN_siteB_1, main = "B: RDP.smooth.dep1 vs siteB")
plot(MODERN_siteB_2, main = "C: RDP.smooth.dep2 vs siteB")

print(MODERN_siteA, digits = 3)

# adjust decay
siteA_dc = decayCorrection(siteA, 10*365*24*3600,"2014-10-6","2015-10-6","%Y-%m-%d")
siteB_dc = decayCorrection(siteB, 10*365*24*3600,"2014-10-6","2015-10-6","%Y-%m-%d")

# test with a sampling site with more FRN values
siteA_rep = c(72,76,74,84,85,75,83,77,81,73)
siteA_var = createSamplingProfile(siteA_rep,30,"site A (10 rep.)")
plot(siteA_var)

MODERN_siteA_var = MODERN(RDP.smooth, siteA_var)
plot(MODERN_siteA_var)
print(MODERN_siteA_var,digits = 3)

# calculate erosion/deposition rates
EDRates = yearlyEDRates(MODERN_siteA_var,
                        massDepth = 100,
                        sampleDepth = GetLayerThickness(siteA_var),
                        samplingTime = "2000",
                        falloutTime = "1963",
                        timeFormat = "%Y")

print(EDRates, digits = 3)

# make reference profile with multiple values
FRN = c(12, 21, 15, 13, 11, 9, 7.5, 4.5, 4, 3, 2.5)
FRN = c(0.8*FRN,FRN,1.2*FRN)
FRN= matrix(FRN, nrow = 11)
name = "Reference Site 1"
myRDP_var = createReferenceProfile(FRN,3, name)
plot(myRDP_var)

# and apply MODERN model
MODERN_myRDP_var_siteA = MODERN(myRDP_var, siteA)
print(MODERN_myRDP_var_siteA, digits = 3)
}
