% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/yearlyEDRates.R
\name{yearlyEDRates}
\alias{yearlyEDRates}
\title{Erosion/Deposition rates}
\usage{
yearlyEDRates(rates, massDepth, sampleDepth, samplingTime, falloutTime,
  timeFormat = "\%Y")
}
\arguments{
\item{rates}{The rate(s) of erosion/deposition expressed in unit length}

\item{massDepth}{The mass depth (kg m^-2)}

\item{sampleDepth}{The depth of the sampling profile (the same unit of rates)}

\item{samplingTime}{The time of measurement (character)}

\item{falloutTime}{The time for comparison (character)}

\item{timeFormat}{The time format used to express the time (default is \%Y-\%m-\%d)}
}
\value{
The yearly soil losses or gains (t ha^-1 yr^-1)
}
\description{
This function transforms the erosion or the deposition rate from length unit
to ton per hectar per year.
}
\examples{
## a simple example
myHeigthSolutions = c(-7.8,-3,-9)
myMassDepth = 110
mySampleDepth = 15
mySamplingTime = '2007'
myFalloutTime = '1954'
myRates = yearlyEDRates(myHeigthSolutions,
               myMassDepth,mySampleDepth,
               mySamplingTime,myFalloutTime)
print('Yearly soil losses or gains (t ha^-1 yr^-1):')
print(myRates)

## an example passing a list of parameters
myHeigthSolutions = c(3,-4)
myMassDepth = c(110,80)
mySampleDepth = c(15,10)
mySamplingTime = c('2015','2000')
myFalloutTime = c('1986','1963')
myRates = yearlyEDRates(myHeigthSolutions,
         myMassDepth,mySampleDepth,
         mySamplingTime,myFalloutTime)

print('Yearly soil losses or gains (t ha^-1 yr^-1):')
print(myRates)

}
\seealso{
TODO
}

